@@ -102,7 +102,7 @@ def exceptions2exit(exception_list):
             try:
                 func(*args, **kwargs)
             except tuple(exception_list) as e:
-                print(e)
+                print("ERROR: {}".format(e))
                 sys.exit(1)
         return func_wrapper
     return exceptions2exit_decorator
@@ -208,5 +208,5 @@ def check_setuptools_version():
         from pkg_resources import parse_version, SetuptoolsVersion  # noqa
     except ImportError:
         raise RuntimeError(
-            "ERROR: Your setuptools version is too old (<12).\n"
+            "Your setuptools version is too old (<12).\n"
             "Use `pip install -U setuptools` to upgrade.")
